# remirepo spec file for php-brotli
#
# SPDX-FileCopyrightText:  Copyright 2017-2025 Remi Collet
# SPDX-License-Identifier: CECILL-2.1
# http://www.cecill.info/licences/Licence_CeCILL_V2-en.txt
#
# Please, preserve the changelog entries
#

%{?scl:%scl_package php-brotli}

%bcond_without      apcu
%bcond_without      libbrotli
%bcond_without      tests

%global pecl_name   brotli
%global pie_vend    kjdev
%global pie_proj    brotli
%global with_zts    0%{!?_without_zts:%{?__ztsphp:1}}
%global ini_name    40-%{pecl_name}.ini
%global sources     %{pecl_name}-%{version}
%global _configure  ../%{sources}/configure

Summary:       Brotli Extension for PHP
Name:          %{?scl_prefix}php-%{pecl_name}
Version:       0.18.0
Release:       1%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
License:       MIT
URL:           https://pecl.php.net/package/%{pecl_name}
Source0:       https://pecl.php.net/get/%{pecl_name}-%{version}%{?prever}.tgz

BuildRequires: make
BuildRequires: %{?dtsprefix}gcc
BuildRequires: %{?scl_prefix}php-devel >= 7.0
BuildRequires: %{?scl_prefix}php-pecl-apcu-devel
BuildRequires: %{?scl_prefix}php-pear
%if %{with libbrotli}
BuildRequires: brotli-devel >= 0.6.0
%else
Provides:      bundled(brotli) = 1.1.0
%endif

Requires:      %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:      %{?scl_prefix}php(api) = %{php_core_api}
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}            = %{version}
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}    = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})           = %{version}
Provides:      %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa}   = %{version}
Provides:      %{?scl_prefix}php-pie(%{pie_vend}/%{pie_proj}) = %{version}
Provides:      %{?scl_prefix}php-%{pie_vend}-%{pie_proj}      = %{version}


%description
PHP extension for compression and decompression with Brotli library.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc

sed -e '/LICENSE/s/role="doc"/role="src"/' -i package.xml

cd %{sources}
%if %{with libbrotli}
# Use the system library
rm -r brotli
sed -e '\:"brotli/:d' -i ../package.xml
%else
cp brotli/LICENSE LICENSE-brotli
%endif

# Sanity check, really often broken
extver=$(sed -n '/#define BROTLI_EXT_VERSION/{s/.* "//;s/".*$//;p}' php_brotli.h)
if test "x${extver}" != "x%{version}%{?gh_date:-dev}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?gh_date:-dev}.
   exit 1
fi
cd ..

mkdir NTS
%if %{with_zts}
mkdir ZTS
%endif

# Drop in the bit of configuration
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension = %{pecl_name}.so

; Configuration
;brotli.output_compression = 0
;brotli.output_compression_level = 11
;brotli.output_compression_dict =
EOF


%build
%{?dtsenable}

cd %{sources}
%{__phpize}
[ -f Makefile.global ] && GLOBAL=Makefile.global || GLOBAL=build/Makefile.global
sed -e 's/INSTALL_ROOT/DESTDIR/' -i $GLOBAL

cd ../NTS
%configure \
    --with-php-config=%{__phpconfig} \
%if %{with libbrotli}
    --with-libbrotli \
%endif
    --with-libdir=%{_lib} \
    --enable-brotli

%make_build

%if %{with_zts}
cd ../ZTS
%configure \
    --with-php-config=%{__ztsphpconfig} \
%if %{with libbrotli}
    --with-libbrotli \
%endif
    --with-libdir=%{_lib} \
    --enable-brotli

%make_build
%endif


%install
%{?dtsenable}

# Install the NTS stuff
%make_install -C NTS
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
# Install the ZTS stuff
%make_install -C ZTS
install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
cd %{sources}
for i in $(grep 'role="doc"' ../package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 $i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done



%check
cd %{sources}

: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'

%if %{with apcu}
: Check that apcu is aware of brotli serializer
%{__php} --no-php-ini \
    --define extension=apcu.so \
    --define apc.enabled=1 \
    --define apc.enable_cli=1 \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --ri apcu | grep '%{pecl_name}'
%endif

%if %{with tests}
: Upstream test suite  for NTS extension
TEST_PHP_EXECUTABLE=%{__php} \
TEST_PHP_ARGS="-n -d extension=%{buildroot}%{php_extdir}/%{pecl_name}.so" \
REPORT_EXIT_STATUS=1 \
%{__php} -n run-tests.php  -q --offline --show-diff
%endif

%if %{with_zts}
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep '^%{pecl_name}$'
%endif


%files
%license %{sources}/LICENSE
%if %{without libbrotli}
%license %{sources}/LICENSE-brotli
%endif
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Wed Jun 18 2025 Remi Collet <remi@remirepo.net> - 0.18.0-1
- update to 0.18.0

* Mon May 19 2025 Remi Collet <remi@remirepo.net> - 0.17.0-1
- update to 0.17.0

* Tue Apr 22 2025 Remi Collet <remi@remirepo.net> - 0.16.0-1
- update to 0.16.0

* Fri Nov  8 2024 Remi Collet <remi@remirepo.net> - 0.15.2-1
- update to 0.15.2

* Wed Nov  6 2024 Remi Collet <remi@remirepo.net> - 0.15.1-1
- update to 0.15.1

* Thu Feb  1 2024 Remi Collet <remi@remirepo.net> - 0.15.0-1
- update to 0.15.0

* Mon Sep  4 2023 Remi Collet <remi@remirepo.net> - 0.14.2-1
- update to 0.14.2 (no change)

* Wed Aug 30 2023 Remi Collet <remi@remirepo.net> - 0.14.0-2
- rebuild for PHP 8.3.0RC1

* Fri Aug  4 2023 Remi Collet <remi@remirepo.net> - 0.14.0-1
- update to 0.14.0
- build out of sources tree
- sources from pecl

* Sat Jan 23 2021 Remi Collet <remi@remirepo.net> - 0.13.1-1
- update to 0.13.1

* Fri Jan 22 2021 Remi Collet <remi@remirepo.net> - 0.13.0-1
- update to 0.13.0

* Fri Jan 15 2021 Remi Collet <remi@remirepo.net> - 0.12.0-1
- update to 0.12.0
- enable apcu serializer with PHP 7+

* Wed Sep 30 2020 Remi Collet <remi@remirepo.net> - 0.11.1-3
- rebuild for PHP 8.0.0RC1

* Wed Sep  2 2020 Remi Collet <remi@remirepo.net> - 0.11.1-2
- rebuild for PHP 8.0.0beta3

* Fri Aug 28 2020 Remi Collet <remi@remirepo.net> - 0.11.1-1
- update to 0.11.1

* Wed Aug  5 2020 Remi Collet <remi@remirepo.net> - 0.11.0-2
- rebuild for 8.0.0beta1

* Tue Aug  4 2020 Remi Collet <remi@remirepo.net> - 0.11.0-1
- update to 0.11.0

* Mon Jul 27 2020 Remi Collet <remi@remirepo.net> - 0.10.0-1
- update to 0.10.0

* Sat Jun 27 2020 Remi Collet <remi@remirepo.net> - 0.9.0-1
- update to 0.9.0

* Fri Jun  5 2020 Remi Collet <remi@remirepo.net> - 0.8.0-1
- update to 0.8.0
- drop patch merged upstream

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.7.0-4
- rebuild for 7.4.0RC1

* Wed Jul 24 2019 Remi Collet <remi@remirepo.net> - 0.7.0-3
- add patch for 7.4.0beta1 from
  https://github.com/kjdev/php-ext-brotli/pull/23

* Tue Jul 23 2019 Remi Collet <remi@remirepo.net> - 0.7.0-2
- rebuild for 7.4.0beta1

* Fri May  3 2019 Remi Collet <remi@remirepo.net> - 0.7.0-1
- update to 0.7.0

* Mon Jan  7 2019 Remi Collet <remi@remirepo.net> - 0.6.2-1
- update to 0.6.2

* Wed Nov 28 2018 Remi Collet <remi@remirepo.net> - 0.6.1-1
- update to 0.6.1 (no change)
- drop patches merged upstream

* Tue Nov 27 2018 Remi Collet <remi@remirepo.net> - 0.6.0-1
- update to 0.6.0, bundled libbrotli 1.0.7
- open https://github.com/kjdev/php-ext-brotli/pull/14 fix version
- open https://github.com/kjdev/php-ext-brotli/pull/15 fix skip
- open https://github.com/kjdev/php-ext-brotli/pull/16 comment

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.5.1-3
- rebuild for 7.3.0beta2 new ABI

* Tue Jul 17 2018 Remi Collet <remi@remirepo.net> - 0.5.1-2
- rebuld for 7.3.0alpha4 new ABI

* Mon Apr 16 2018 Remi Collet <remi@remirepo.net> - 0.5.1-1
- update to 0.5.1, bundled libbrotli 1.0.4
- open https://github.com/kjdev/php-ext-brotli/pull/9 fix version

* Thu Nov  9 2017 Remi Collet <remi@remirepo.net> - 0.5.0-1
- new package, version 0.5.0, bundled libbrotli 1.0.1
- add patch to build with system libbrotli
  open https://github.com/kjdev/php-ext-brotli/pull/6

